Intent

Struct Intent 

pub struct Intent { /* private fields */ }
Intent structure which represents user intent.

Implementations

Source

impl Intent

Intent structure implementation.

pub fn new( args: Vec<String>, command: CommandSummary, supcommands: Vec<CommandSummary>, subcommands: Vec<CommandSummary>, flags: Vec<FlagSummary>, params: Vec<ParamSummary>, resources: Vec<ResourceSummary>, ) -> Self

Returns new instance.

pub fn args(&self) -> &Vec<String>

Returns raw command-line arguments.

pub fn command(&self) -> &CommandSummary

Returns summary objects of the executed command.

pub fn supcommands(&self) -> &Vec<CommandSummary>

Returns summary objects of parent commands in a tree.

pub fn subcommands(&self) -> &Vec<CommandSummary>

Returns summary objects of child commands.

pub fn flags(&self) -> &Vec<FlagSummary>

Returns summary objects of all flags.

pub fn flag<S: Into<String>>(&self, name: S) -> Option<&FlagSummary>

Returns summary objects of a specific flag.

pub fn params(&self) -> &Vec<ParamSummary>

Returns summary objects of all params.

pub fn param<S: Into<String>>(&self, name: S) -> Option<&ParamSummary>

Returns summary objects of a specific flag.

pub fn resources(&self) -> &Vec<ResourceSummary>

Returns summary objects of all resources.

pub fn resource<S: Into<String>>(&self, name: S) -> Option<&ResourceSummary>

Returns summary objects of a specific resource.

pub fn has_args(&self) -> bool

Returns true if command-line arguments are present.

pub fn has_arg<S: Into<String>>(&self, name: S) -> bool

Returns true if command-line argument is present.

pub fn has_supcommands(&self) -> bool

Returns true if the executed command has parent commands.

pub fn has_subcommands(&self) -> bool

Returns true if the executed command has child commands.

pub fn has_flags(&self) -> bool

Returns true if the executed command has flags.

pub fn has_flag<S: Into<String>>(&self, name: S) -> bool

Returns true if flag is present.

pub fn has_provided_flag<S: Into<String>>(&self, name: S) -> bool

Returns true if flag is present.

pub fn has_params(&self) -> bool

Returns true if the executed command has params.

pub fn has_param<S: Into<String>>(&self, name: S) -> bool

Returns true if param is present.

pub fn has_provided_param<S: Into<String>>(&self, name: S) -> bool

Returns true if param is present.

pub fn has_resources(&self) -> bool

Returns true if the executed command has resources.

pub fn has_resource<S: Into<String>>(&self, name: S) -> bool

Returns true if resource is present.